@@ -1,8 +1,8 @@
 import sys
 import optparse
-import re
 from optparse import Option, BadOptionError
 
+import re
 from texttable import Texttable
 import os
 from rider.cli import cmdoptions
@@ -317,13 +317,11 @@ class WRiderCommand(Command):
                      binds={cert_path: {'bind': docker_cert_path, 'ro': False}})
         h_port = client.port(container_id, 5000)
         docker_host_ip = self.get_docker_host_ip()
-        msg = '''
-        \n
-        You need to do below two steps to use your Wrider container ready:
-        1. sudo echo "{i}   boot2docker" >> /etc/hosts
-        2. Open your browser and access http://boot2docker:{p}
-        \n
-        '''.format(i=docker_host_ip, p=h_port[0].get('HostPort'))
+        msg = '\n\
+        You need to do below two steps to use your Wrider container ready:\n \
+        1. sudo echo "{i}   boot2docker" >> /etc/hosts\n \
+        2. Open your browser and access http://boot2docker:{p}\n \
+        '.format(i=docker_host_ip, p=h_port[0].get('HostPort'))
         sys.stdout.write(msg)
 
     def get_docker_host_ip(self):
