@@ -1,12 +1,15 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-import os
 import sys
 
+import os
+
+
 TRUE_BOOLEAN = ("YES", "Y")
 FALSE_BOOLEAN = ("NO", "N")
 
+
 def get_prog():
     return 'rider'
 
@@ -44,7 +47,7 @@ def get_terminal_size():
     return int(cr[1]), int(cr[0])
 
 
-def get_userinput(msg, retry=3):
+def get_userinput_boolean(msg, retry=3):
     for i in xrange(retry):
         resp = raw_input(msg)
         if resp.upper() in TRUE_BOOLEAN + FALSE_BOOLEAN:
@@ -55,5 +58,39 @@ def get_userinput(msg, retry=3):
     return resp
 
 
+def get_userinput_str(msg, retry=3):
+    for i in xrange(3):
+        resp = raw_input(msg)
+        if not resp or len(resp) == 0:
+            continue
+        return resp
+
+
+def get_userinput_int(msg, retry=3):
+    for i in xrange(3):
+        resp = raw_input(msg)
+        try:
+            int_resp = int(resp)
+            return int_resp
+        except ValueError:
+            continue
+
+
+def get_userinput_choice(choice_list, message, retry=3):
+    choice_message_list = ["%s : %s " % (i + 1, v) for i, v in enumerate(choice_list)]
+    msg_list = [message]
+    msg_list.extend(choice_message_list)
+    msg_list.append("Your choose is : ")
+    for i in xrange(3):
+        resp = raw_input("\n".join(msg_list))
+        try:
+            int_resp = int(resp)
+            if int_resp < 1 or int_resp > len(choice_list):
+                return
+            return choice_list[int_resp - 1]
+        except ValueError:
+            continue
+
+
 def is_true(value):
     return value.upper() in TRUE_BOOLEAN
