@@ -4,6 +4,7 @@ from pkg.fig.project import Project
 from pkg.fig.service import VALID_NAME_CHARS, ConfigError, NAME_RE
 from pkg.fig.cli.docker_client import docker_client
 from service import Service
+from clint.textui.progress import Bar
 
 CONTAINER_NAME_REGEX = '\s+\_\d+\_\s+\_\d+'
 DEFAULT_IMAGE = '10.66.128.203:49153/coreqa/rider_splunk:49888'
@@ -107,8 +108,8 @@ class Environment(object):
     def get_environment_by_name(cls, name):
         """
         Return the environment object specified by name ([env_name]_[env_type])
-        :param name: string name = env_name+"_"+env_type
 
+        :param name: string name = env_name+"_"+env_type
         :return:    environment object
 
         >>> from rider.environment import Environment
@@ -180,7 +181,10 @@ class Environment(object):
 
         # check the ssh
         for service in self.service_list:
-            service.ssh_check()
+            progress_bar = Bar(label="waiting %s --> " % service.name)
+            service.ssh_check(progress_bar)
+            progress_bar.show(100, 100)
+            progress_bar.done()
 
     def bootstrap(self):
         """
@@ -199,8 +203,8 @@ class Environment(object):
         # self.indexer.scale(3)
         #
         # elif self.env_type == "multisite":
-        #     self.up()
-        #     self.site1indexer.scale(3)
+        # self.up()
+        # self.site1indexer.scale(3)
         #     self.site2indexer.scale(3)
         #     self.site3indexer.scale(3)
         #
@@ -306,8 +310,8 @@ ENV_DICT_MAPPING = {
     # ShcEnvironment.env_type: [
     # {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'sh', 'ports': ['8000', '8089', '22'],
     # 'links': ['master'], u'name': 'sh'},
-    #     {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'master', 'ports': ['8000', '8089', '22'],
-    #      u'name': 'master'},
+    # {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'master', 'ports': ['8000', '8089', '22'],
+    # u'name': 'master'},
     #     {'image': '10.66.128.203:49153/coreqa/splunk:fig', 'command': 'indexer', 'ports': ['8000', '8089', '22'],
     #      'links': ['master'], u'name': 'indexer'}]
 }
