@@ -1,5 +1,6 @@
 import time
 
+from clint.textui.progress import Bar
 from machine import Machine
 
 
@@ -27,7 +28,12 @@ class Service(object):
             before_scale = self.machines
             before_scale_machine_name = [machine.name for machine in self.machines]
             self._service.scale(desire_number)
-            self.ssh_check()
+
+            progress_bar = Bar("scaling %s" % self.name)
+            self.ssh_check(progress_bar)
+            progress_bar.show(100, 100)
+            progress_bar.done()
+
             after_scale = self.machines
             need_to_deploy = [item for item in after_scale if item.name not in before_scale_machine_name]
 
@@ -93,15 +99,18 @@ class Service(object):
             machines.append(Machine(_container, self))
         return machines
 
-    def ssh_check(self):
+    def ssh_check(self, progress_bar):
         retry = 0
-        while retry < 10:
+        progress = 10
+        while retry < 100:
             for machine in self.machines:
+                progress_bar.show(progress, 100)
                 if not machine.is_ssh_accessible:
                     break
             else:
                 return True
-            time.sleep(10)
+            progress += 3
+            time.sleep(2)
             retry += 1
         else:
             # FIXME catagory the exception
